* This file computes the best fitting threshold for each of our receiver
* It also computes what threshold would be recovered for each of our receiver if he actually followed Bayes rule

// Thresholds vs Bayesian Thresholds
sort oid

* t_t is the "top" threshold, t_b is the "bottom" threshold
gen t_b = .
gen t_t = .
* f_t is the fraction of choices consistent with t_t, f_b with t_b
gen f_b = .
gen f_t = .

* reshape the data
rename aggpost_red post_1
rename aggpost_blue post_2
rename aggpost_none post_3
rename mrdec mdec_1
rename mbdec mdec_2
rename mndec mdec_3
reshape long post_ mdec_, i(oid match) j(post_for)
rename post_ post
rename mdec_ mdec
drop if post == .   /* no well defined posteriors in a few cases */

* because of the way the data is stacked, I need to loop through all three messages for each match
* not all oid have the same number of obs becasue we drop post == . (see above)
bysort oid (post): gen match_color = _n

* generate a synthetic decision of a Bayesian responder
gen b_dec = ( post >= 0.5 )
gen b_t_b = .
gen b_t_t = .

* threshold
sum oid
* loop of subjects
forvalues i = 1/`r(max)' {
*  forvalues i = 100/100 {
  gen lower_val = 0 if oid == `i'
  gen upper_val = 0 if oid == `i'
  gen lower_bound = 0 if oid == `i'
  gen upper_bound = 0 if oid == `i'
  * same for Bayesian responder
  gen b_lower_val = 0 if oid == `i'
  gen b_upper_val = 0 if oid == `i'
  gen b_lower_bound = 0 if oid == `i'
  gen b_upper_bound = 0 if oid == `i'
  * loop over potential thresholds
  forvalues j = 0(1)101 {
    local j = `j'/100
    gen foo = ( post >= `j' ) if oid == `i'
    egen bar = mean( ( mdec == foo ) ) if oid == `i'
    replace lower_bound = `j' if bar > lower_val & oid == `i'
    replace upper_bound = `j' if bar >= upper_val & oid == `i'
    replace lower_val = bar if bar > lower_val & oid == `i'
    replace upper_val = bar if bar >= upper_val & oid == `i'
    drop foo bar
    * same for Bayesian responder
    gen foo = ( post >= `j' ) if oid == `i'
    egen bar = mean( ( b_dec == foo ) ) if oid == `i'
    replace b_lower_bound = `j' if bar > b_lower_val & oid == `i'
    replace b_upper_bound = `j' if bar >= b_upper_val & oid == `i'
    replace b_lower_val = bar if bar > b_lower_val & oid == `i'
    replace b_upper_val = bar if bar >= b_upper_val & oid == `i'
    drop foo bar
  }
  replace t_t = upper_bound if oid == `i'
  replace t_b = lower_bound if oid == `i'
  replace f_t = upper_val if oid == `i'
  replace f_b = lower_val if oid == `i'
  drop lower_val upper_val lower_bound upper_bound
  * same for Bayesian responder
  replace b_t_t = b_upper_bound if oid == `i'
  replace b_t_b = b_lower_bound if oid == `i'
  drop b_lower_val b_upper_val b_lower_bound b_upper_bound
}

* replace top code (from 1.01 to 1.2) for better graph
replace t_t = 1.2 if t_t > 1
replace t_b = 1.2 if t_b > 1
replace b_t_t = 1.2 if b_t_t > 1
replace b_t_b = 1.2 if b_t_b > 1
* replace top code if > 1 when bottom threshold <= 1
replace t_t = 1 if t_b <= 1 & t_t > 1
replace b_t_t = 1 if b_t_b <= 1 & b_t_t > 1

* mid-point
gen t_m = ( t_t + t_b ) / 2
gen b_t_m = ( b_t_t + b_t_b ) / 2



