**************************** WARNING ****************************
* Be carefull to use id for senders and oid for receivers       *
*****************************************************************

***************************
* START
* Compute power for test such as in the right panel of Figure 2
use "data_for_stata.dta", clear
keep if v80 == 1

* first number is ball, second is message
* 1 is red, 2 is blue, 3 is no_message
gen diff_22 = bblue - revbblue

* estimate difference in prob of red between commitment and revision
xtreg diff_22, i(id)
local alpha = _b[_cons]
local sigma_u = `e(sigma_u)'
local sigma_e = `e(sigma_e)'

* set stuff up for simulation
local no_sim = 1000
set seed 1234
mat p = J(`no_sim',1,0)
mat reject = J(`no_sim',1,0)

* simulation
forval sim = 1(1)`no_sim' {
	quietly{
	clear
	set obs 32		/* 16 (subjects) x 4 (sessions) / 2 (roles) */
	generate id = _n
	generate u_i = rnormal(0,`sigma_u')		/* blue message / blue ball */
	expand 10
	bysort id: generate round = _n
	generate e_ij = rnormal(0,`sigma_e')	/* blue message / blue ball */
	generate y = `alpha' + u_i + e_ij				/* blue message / blue ball: with this (the actual) difference, reject null 0.969 of the time */
	generate session = 1				/* each simulated session has 80 observations (per role): 16 (subject) / 2 (roles) * 10 matches */
	replace session = 2 if _n > 80
	replace session = 3 if _n > 160
	replace session = 4 if _n > 240

	xtreg y, i(id) cluster(session)
	mat foo = r(table)
	sca bar = foo[4,1]
	mat p[`sim',1] = bar
	sca baz = ( bar < 0.05 )
	mat reject[`sim',1] = baz
	}
}

* report simulation results
clear
set obs `no_sim'
svmat p
svmat reject
sum p reject

*************************** Power for Figure 2 test END
*/


***************************
* START
* Compute minimal detectable effect size for test such as in the right panel of Figure 2 at 80% power
* figured out by trying different values
* ANSWER IS 12.8
use "data_for_stata.dta", clear
keep if v80 == 1

* first number is ball, second is message
* 1 is red, 2 is blue, 3 is no_message
gen diff_22 = bblue - revbblue

* estimate difference in prob of red between commitment and revision
xtreg diff_22, i(id)
local alpha = _b[_cons]
local sigma_u = `e(sigma_u)'
local sigma_e = `e(sigma_e)'

* set stuff up for simulation
local no_sim = 1000
set seed 1234
mat p = J(`no_sim',1,0)
mat reject = J(`no_sim',1,0)

* simulation
forval sim = 1(1)`no_sim' {
	quietly{
	clear
	set obs 32		/* 16 (subjects) x 4 (sessions) / 2 (roles) */
	generate id = _n
	generate u_i = rnormal(0,`sigma_u')		/* blue message / blue ball */
	expand 10
	bysort id: generate round = _n
	generate e_ij = rnormal(0,`sigma_e')	/* blue message / blue ball */
	generate y = 12.8 + u_i + e_ij				/* blue message / blue ball: with this (the actual) difference, reject null 0.969 of the time */
	generate session = 1				/* each simulated session has 80 observations (per role): 16 (subject) / 2 (roles) * 10 matches */
	replace session = 2 if _n > 80
	replace session = 3 if _n > 160
	replace session = 4 if _n > 240

	xtreg y, i(id) cluster(session)
	mat foo = r(table)
	sca bar = foo[4,1]
	mat p[`sim',1] = bar
	sca baz = ( bar < 0.05 )
	mat reject[`sim',1] = baz
	}
}

* report simulation results
clear
set obs `no_sim'
svmat p
svmat reject
sum p reject

*************************** Minimal detectable effect size for Figure 2 test END
*/


***************************
* START
* Compute power for test such as in the left panel of Figure 3
clear mata
use "data_for_stata.dta", clear
keep if u20 == 1 | u100 == 1

gen post_above = ( post_red >= 0.5 ) if post_red ~= .

sum mrdec if post_above == 1 & u20 == 1
sum mrdec if post_above == 1 & u100 == 1

* Comparing rates in u20 and u100 for posteriors above 0.5
* post_above_u20 will be exclude category to make test "direct"
gen post_above_u20 = post_above * ( treatment == "U20" )
gen post_above_u100 = post_above * ( treatment == "U100" )
gen post_below_u20 = ( 1 - post_above ) * ( treatment == "U20" )
gen post_below_u100 = ( 1 - post_above ) * ( treatment == "U100" )
xtreg mrdec post_below_u20 post_below_u100 post_above_u100, i(oid)
local b_above_20 = _b[_cons]
local b_above_100 = _b[post_above_u100]
local sigma_u = `e(sigma_u)'
local sigma_e = `e(sigma_e)'

* set stuff up for simulation
local no_sim = 1000
set seed 1234
mat p = J(`no_sim',1,0)
mat reject = J(`no_sim',1,0)

* simulation
forval sim = 1(1)`no_sim' {
	quietly{
	clear
	set obs 64		/* 16 (subjects) x 4 (sessions) x 2 (treatments) / 2 (roles) */
	generate id = _n
	generate u_i = rnormal(0,`sigma_u')
	expand 5		/* we have an average of 152 obs of posteriors >= 0.5 per treatment; that comes to a little under 5 per subject (5 gives 160 per treatment) */
	bysort id: generate round = _n
	generate e_ij = rnormal(0,`sigma_e')
	generate u100 = ( _n > 160 )
	generate y = `b_above_20' + u_i + e_ij
	replace y = y + `b_above_100' if u100 == 1
	replace y = ( y >= 0.5 )
	generate session = 1				/* each simulated session has 40 observations (per role): 16 (subject) / 2 (roles) * 5 matches */
	replace session = 2 if _n > 40
	replace session = 3 if _n > 80
	replace session = 4 if _n > 120
	replace session = 5 if _n > 160
	replace session = 6 if _n > 200
	replace session = 7 if _n > 240
	replace session = 8 if _n > 280
	xtreg y u100, i(id) cluster(session)
	mat foo = r(table)
	sca bar = foo[4,1]
	mat p[`sim',1] = bar
	sca baz = ( bar < 0.05 )
	mat reject[`sim',1] = baz
	}
}

* report simulation results
clear
set obs `no_sim'
svmat p
svmat reject
sum p reject

*************************** Power for Figure 3 test END
*/


***************************
* START
* Minimal detectable effect size for test such as in the left panel of Figure 3 at 80% power
* figured out by trying different values
* ANSWER IS 0.241
clear mata
use "data_for_stata.dta", clear
keep if u20 == 1 | u100 == 1

gen post_above = ( post_red >= 0.5 ) if post_red ~= .

sum mrdec if post_above == 1 & u20 == 1
sum mrdec if post_above == 1 & u100 == 1

* Comparing rates in u20 and u100 for posteriors above 0.5
* post_above_u20 will be exclude category to make test "direct"
gen post_above_u20 = post_above * ( treatment == "U20" )
gen post_above_u100 = post_above * ( treatment == "U100" )
gen post_below_u20 = ( 1 - post_above ) * ( treatment == "U20" )
gen post_below_u100 = ( 1 - post_above ) * ( treatment == "U100" )
xtreg mrdec post_below_u20 post_below_u100 post_above_u100, i(oid)
local b_above_20 = _b[_cons]
local b_above_100 = _b[post_above_u100]
local sigma_u = `e(sigma_u)'
local sigma_e = `e(sigma_e)'

* set stuff up for simulation
local no_sim = 1000
set seed 1234
mat p = J(`no_sim',1,0)
mat reject = J(`no_sim',1,0)

* simulation
forval sim = 1(1)`no_sim' {
	quietly{
	clear
	set obs 64		/* 16 (subjects) x 4 (sessions) x 2 (treatments) / 2 (roles) */
	generate id = _n
	generate u_i = rnormal(0,`sigma_u')
	expand 5		/* we have an average of 152 obs of posteriors >= 0.5 per treatment; that comes to a little under 5 per subject (5 gives 160 per treatment) */
	bysort id: generate round = _n
	generate e_ij = rnormal(0,`sigma_e')
	generate u100 = ( _n > 160 )
	generate y = `b_above_20' + u_i + e_ij
	replace y = y + 0.241 if u100 == 1
	replace y = ( y >= 0.5 )
	generate session = 1				/* each simulated session has 40 observations (per role): 16 (subject) / 2 (roles) * 5 matches */
	replace session = 2 if _n > 40
	replace session = 3 if _n > 80
	replace session = 4 if _n > 120
	replace session = 5 if _n > 160
	replace session = 6 if _n > 200
	replace session = 7 if _n > 240
	replace session = 8 if _n > 280
	xtreg y u100, i(id) cluster(session)
	mat foo = r(table)
	sca bar = foo[4,1]
	mat p[`sim',1] = bar
	sca baz = ( bar < 0.05 )
	mat reject[`sim',1] = baz
	}
}

* report simulation results
clear
set obs `no_sim'
svmat p
svmat reject
sum p reject

*************************** Minimal detectable effect size for Figure 3 test END
*/


***************************
* START
* Compute power for test such as in the left panel of Figure 3
* IF we had not used the strategy method
clear mata
use "data_for_stata.dta", clear
keep if u20 == 1 | u100 == 1

gen post_above = ( post_red >= 0.5 ) if post_red ~= .

* how many observations if we did not use the strategy method? (Answer 112 in u20 and 51 in u100)
sum mrdec if post_above == 1 & u20 == 1 & message == 1
sum mrdec if post_above == 1 & u100 == 1 & message == 1

* Comparing rates in u20 and u100 for posteriors above 0.5
* post_above_u20 will be exclude category to make test "direct"
gen post_above_u20 = post_above * ( treatment == "U20" )
gen post_above_u100 = post_above * ( treatment == "U100" )
gen post_below_u20 = ( 1 - post_above ) * ( treatment == "U20" )
gen post_below_u100 = ( 1 - post_above ) * ( treatment == "U100" )
xtreg mrdec post_below_u20 post_below_u100 post_above_u100, i(oid)
local b_above_20 = _b[_cons]
local b_above_100 = _b[post_above_u100]
local sigma_u = `e(sigma_u)'
local sigma_e = `e(sigma_e)'

* set stuff up for simulation
local no_sim = 1000
set seed 1234
mat p = J(`no_sim',1,0)
mat reject = J(`no_sim',1,0)

* simulation
forval sim = 1(1)`no_sim' {
	quietly{
	clear
	set obs 64		/* 16 (subjects) x 4 (sessions) x 2 (treatments) / 2 (roles) */
	generate id = _n
	generate u_i = rnormal(0,`sigma_u')
	expand 3		/* we will have 3 obs per subject for u20 and 2 for u100 */
	bysort id: generate round = _n
	generate e_ij = rnormal(0,`sigma_e')
	generate u100 = ( _n > 96 )
	drop if u100 == 1 & round == 3	/* make it 2 obs per subject for u100 */
	generate y = `b_above_20' + u_i + e_ij
	replace y = y + `b_above_100' if u100 == 1
	replace y = ( y >= 0.5 )
	generate session = 1				/* each simulated session has 40 observations (per role): 16 (subject) / 2 (roles) * 5 matches */
	replace session = 2 if _n > 24
	replace session = 3 if _n > 48
	replace session = 4 if _n > 72
	replace session = 5 if _n > 96
	replace session = 6 if _n > 112
	replace session = 7 if _n > 128
	replace session = 8 if _n > 144
	xtreg y u100, i(id) cluster(session)
	mat foo = r(table)
	sca bar = foo[4,1]
	mat p[`sim',1] = bar
	sca baz = ( bar < 0.05 )
	mat reject[`sim',1] = baz
	}
}

* report simulation results
clear
set obs `no_sim'
svmat p
svmat reject
sum p reject

*************************** Power for Figure 3 test IF no strategy method END
*/

