* This do file replicates stat tests reported in the body of the text using different specifications
* These results will be compiled in an appendix
* it was first created on 10/19/18


**************************** WARNING ****************************
* Be carefull to use id for senders and oid for receivers       *
*****************************************************************


// Figure 2 related tests
// About right panel (V80)
use "data_for_stata.dta", clear
keep if rho == 80

* first number is ball, second is message
* 1 is red, 2 is blue, 3 is no_message
gen diff_11 = rred - revrred
gen diff_12 = rblue - revrblue
gen diff_13 = rnone - revrnone
gen diff_21 = bred - revbred
gen diff_22 = bblue - revbblue
gen diff_23 = bnone - revbnone

xtreg diff_11 if treatment == "V80", i(id) cluster(session)
meglm diff_11 if treatment == "V80" || date : || id :
* it turns out not to be trunctaed
//metobit diff_11 if treatment == "V80" || id : , vce(cluster session) ll(-100) ul(100)
//metobit diff_11 if treatment == "V80" || date : || oid :, ll(-100) ul(100)
* Can't do FE.

// About left panel (U80)
* joint test for U80 (for V80 one probability implies the other)
reshape long diff_, i(id match) j(ball_message)

rename diff_ diff
gen d_11 = ( ball_message == 11 )
gen d_12 = ( ball_message == 12 )
gen d_13 = ( ball_message == 13 )
gen d_21 = ( ball_message == 21 )
gen d_22 = ( ball_message == 22 )
gen d_23 = ( ball_message == 23 )
gen state = 1 if ball_message <= 13
replace state = 2 if ball_message >= 21

* About the tests below. With 3 probabilities, 2 imply the third; hence if d_12 == 1, changes in the one left imply changes in the other.
* Hence, this tests whether 2 of the changes are different from 0.
* First when the ball is red
xtreg diff d_13 if state == 1 & d_12 ~= 1 & treatment == "U80", i(id) cluster( session )
test _cons = 0
test d_13 = 0, accum
meglm diff d_13 if state == 1 & d_12 ~= 1 & treatment == "U80" || date : || id :
test _cons = 0
test d_13 = 0, accum
* second when the ball is blue
xtreg diff d_23 if state == 2 & d_22 ~= 1 & treatment == "U80", i(id) cluster( session )
test _cons = 0
test d_23 = 0, accum
meglm diff d_23 if state == 2 & d_22 ~= 1 & treatment == "U80" || date : || id :
test _cons = 0
test d_23 = 0, accum


// test to compare correlation with Bayesian receivers
use "data_for_stata.dta", clear
keep if rho == 80

rename phi_bayes_com phi_bayes_1
rename phi_bayes_rev phi_bayes_2

reshape long phi_bayes_, i(id match) j(stage)
rename phi_bayes_ phi_bayes
gen stage_2 = ( stage == 2 )

bysort stage: sum phi_bayes if treatment == "U80"
bysort stage: sum phi_bayes if treatment == "V80"

preserve
keep if treatment == "U80"
xtreg phi_bayes stage_2, i(id) cluster( session )
meglm phi_bayes stage_2 || date : || id :
metobit phi_bayes stage_2 || id : , vce(cluster session) ll(0) ul(1)
metobit phi_bayes stage_2 || date : || id :,  ll(0) ul(1)
* clustse FE fails so in all but 1 cluster so I omit the next two
*clustse regress phi_bayes stage_2 , cluster(session) seed(1234) fe(yes) festruc(id)
*xtreg phi_bayes stage_2 , cluster(session) i(id) fe


restore
keep if treatment == "V80"
xtreg phi_bayes stage_2, i(id) cluster( session )
meglm phi_bayes stage_2 || date : || id :
metobit phi_bayes stage_2 || id : , vce(cluster session) ll(0) ul(1)
metobit phi_bayes stage_2 || date : || id :, ll(0) ul(1) intmethod(mc)	/* the other intergration method crash maybe because the random effects estimate on date is almost zero */
* clustse FE fails so in all but 1 cluster so I omit the next two
*clustse regress phi_bayes stage_2 , cluster(session) seed(1234) fe(yes) festruc(id)
*xtreg phi_bayes stage_2 , cluster(session) i(id) fe


// Figure 3 related tests
use "data_for_stata.dta", clear

gen post_above = ( post_red >= 0.5 ) if post_red ~= .

* U20 & U100
* Test comparing rates below and above
preserve
keep if treatment == "U20" |  treatment == "U100"
gen post_above_u20 = post_above * ( treatment == "U20" )
gen post_above_u100 = post_above * ( treatment == "U100" )
gen post_below_u20 = ( 1 - post_above ) * ( treatment == "U20" )
gen post_below_u100 = ( 1 - post_above ) * ( treatment == "U100" )
xtreg mrdec post_above_u20 post_below_u100 post_above_u100 if treatment == "U20" | treatment == "U100", i(oid) cluster(session)
* Note that FE cannot be estimated as is for the above due to collinearity
test post_above_u20 = post_above_u100 
meglm mrdec post_above_u20 post_below_u100 post_above_u100 || date : || oid :
test post_above_u20 = post_above_u100 
meprobit mrdec post_above_u20 post_below_u100 post_above_u100 || oid : , vce(cluster session)
test post_above_u20 = post_above_u100 
meprobit mrdec post_above_u20 post_below_u100 post_above_u100 || date : || oid :
test post_above_u20 = post_above_u100 

restore
drop post_above
gen post_above = ( post_none >= 0.5 ) if post_none ~= .
preserve

* V20 & V100
* Test comparing rates below and above
restore
keep if treatment == "V20" |  treatment == "V100"
gen post_above_v20 = post_above * ( treatment == "V20" )
gen post_above_v100 = post_above * ( treatment == "V100" )
gen post_below_v20 = ( 1 - post_above ) * ( treatment == "V20" )
gen post_below_v100 = ( 1 - post_above ) * ( treatment == "V100" )
xtreg mndec post_above_v20 post_below_v100 post_above_v100 if treatment == "V20" | treatment == "V100", i(oid) cluster(session)
test post_above_v20 = post_above_v100 
meglm mndec post_above_v20 post_below_v100 post_above_v100 || date : || oid :
test post_above_v20 = post_above_v100 
meprobit mndec post_above_v20 post_below_v100 post_above_v100 || oid : , vce(cluster session)
test post_above_v20 = post_above_v100 
meprobit mndec post_above_v20 post_below_v100 post_above_v100 || date : || oid :
test post_above_v20 = post_above_v100 


// Related to Table 3
// Bayesian correlation between Ball and Guess by treatment (at the end)
// Using not the realization but the complete strategy
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"
preserve

* Phi Bayes -- Bottom left panel of Table 4
keep if ( v20 == 1 | v80 == 1 )
xtreg phi_bayes_agg v80 if ( v20 == 1 | v80 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg v80 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_bayes_agg v80 || id : , vce(cluster session)
*metobit phi_bayes_agg v80 || date : || id :
restore
preserve
keep if ( v80 == 1 | v100 == 1 )
xtreg phi_bayes_agg v100 if ( v80 == 1 | v100 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg v100 || date : || id :
sum phi_actual_agg
metobit phi_bayes_agg v100 || id : , vce(cluster session) ll(0) ul(1)
metobit phi_bayes_agg v100 || date : || id :, ll(0) ul(1)
restore
preserve
keep if ( u20 == 1 | u80 == 1 )
xtreg phi_bayes_agg u80 if ( u20 == 1 | u80 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg u80 || date : || id :
sum phi_actual_agg
* turns out not to be censored below
*metobit phi_bayes_agg u80 || id : , vce(cluster session)
*metobit phi_bayes_agg u80 || date : || id :
restore
preserve
keep if ( u80 == 1 | u100 == 1 )
xtreg phi_bayes_agg u100 if ( u80 == 1 | u100 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg u100 || date : || id :
sum phi_actual_agg
* turns out not to be censored below
metobit phi_bayes_agg u100 || id : , vce(cluster session) ul(1)
metobit phi_bayes_agg u100 || date : || id :, ul(1)
restore
preserve
keep if ( v20 == 1 | u20 == 1 )
xtreg phi_bayes_agg u20 if ( v20 == 1 | u20 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg v20 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_bayes_agg v20 || id : , vce(cluster session)
*metobit phi_bayes_agg v20 || date : || id :
restore
preserve
keep if ( v80 == 1 | u80 == 1 )
xtreg phi_bayes_agg u80 if ( v80 == 1 | u80 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg v80 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_bayes_agg v80 || id : , vce(cluster session)
*metobit phi_bayes_agg v80 || date : || id :
restore
preserve
keep if ( v100 == 1 | u100 == 1 )
xtreg phi_bayes_agg u100 if ( v100 == 1 | u100 == 1 ), i(id) cluster(session)
meglm phi_bayes_agg u100 || date : || id :
sum phi_actual_agg
* turns out not to be censored below
metobit phi_bayes_agg u100 || id : , vce(cluster session) ul(1)
metobit phi_bayes_agg u100 || date : || id :, ul(1)


// Correlation between Ball and Guess by treatment (at the end)
// Using not the realization but the complete strategy
restore
preserve

keep if ( v20 == 1 | v80 == 1 )
xtreg phi_actual_agg v80 if ( v20 == 1 | v80 == 1 ), i(id) cluster(session)
meglm phi_actual_agg v80 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_actual_agg v80 || id : , vce(cluster session) ll(0) ul(1)
*metobit phi_actual_agg v80 || date : || id :, ll(0) ul(1)
restore
preserve
keep if ( v80 == 1 | v100 == 1 )
xtreg phi_actual_agg v100 if ( v80 == 1 | v100 == 1 ), i(id) cluster(session)
meglm phi_actual_agg v100 || date : || id :
sum phi_actual_agg
metobit phi_actual_agg v100 || id : , vce(cluster session) ll(0) ul(1)
metobit phi_actual_agg v100 || date : || id :, ll(0) ul(1)
restore
preserve
keep if ( u20 == 1 | u80 == 1 )
xtreg phi_actual_agg u80 if ( u20 == 1 | u80 == 1 ), i(id) cluster(session)
meglm phi_actual_agg u80 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_actual_agg u80 || id : , vce(cluster session)
*metobit phi_actual_agg u80 || date : || id :
restore
preserve
keep if ( u80 == 1 | u100 == 1 )
xtreg phi_actual_agg u100 if ( u80 == 1 | u100 == 1 ), i(id) cluster(session)
meglm phi_actual_agg u100 || date : || id :
sum phi_actual_agg
* turns out not to be censored below
metobit phi_actual_agg u100 || id : , vce(cluster session) ul(1)
metobit phi_actual_agg u100 || date : || id :, ul(1)
restore
preserve
keep if ( v20 == 1 | u20 == 1 )
xtreg phi_actual_agg u20 if ( v20 == 1 | u20 == 1 ), i(id) cluster(session)
meglm phi_actual_agg v20 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_actual_agg v20 || id : , vce(cluster session)
*metobit phi_actual_agg v20 || date : || id :
restore
preserve
keep if ( v80 == 1 | u80 == 1 )
xtreg phi_actual_agg u80 if ( v80 == 1 | u80 == 1 ), i(id) cluster(session)
meglm phi_actual_agg v80 || date : || id :
sum phi_actual_agg
* turns out not to be censored
*metobit phi_actual_agg v80 || id : , vce(cluster session)
*metobit phi_actual_agg v80 || date : || id :
restore
preserve
keep if ( v100 == 1 | u100 == 1 )
xtreg phi_actual_agg u100 if ( v100 == 1 | u100 == 1 ), i(id) cluster(session)
meglm phi_actual_agg u100 || date : || id :
sum phi_actual_agg
* turns out not to be censored below
metobit phi_actual_agg u100 || id : , vce(cluster session)  ul(1)
metobit phi_actual_agg u100 || date : || id :,  ul(1)
