* All data analysis, computations, tests, performed in Stata

* setting up stuff
clear
clear matrix
capture log close
set more 1
set mem 100m

* You may set the path  for the directory where main.do is below
* cd "foo"

**************************** WARNING ****************************
* Be carefull to use id for senders and oid for receivers       *
*****************************************************************





// SECTION 3.1


// Pages 11-12
// No of session and subjects in "main sessions"
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"
keep if match == 16			/* Keep one obs per subject */
bysort treatment: tab date  /* number of sessions per treatment */
gen foo = .
bysort date: replace foo = _N
replace foo = 2 * foo		/* the data is organized by sender, there is a receiver for each sender */
bysort date: keep if _n == 1
sum foo                     /* number of subjects per session */
egen bar = sum(foo)
sum bar                     /* total number of subjects */

knadfknvkd


// SECTION 4.1.1


// Power Calculations mentioned in Footenote 19, page 17
do "est_flp_power.do"


// Page 17-18
// Data to accompany Figure 2
use "data_for_stata.dta", clear
keep if rho == 80

* first number is ball, second is message
* 1 is red, 2 is blue, 3 is no_message
gen diff_11 = rred - raw_revrred
gen diff_12 = rblue - raw_revrblue
gen diff_13 = rnone - raw_revrnone
gen diff_21 = bred - raw_revbred
gen diff_22 = bblue - raw_revbblue
gen diff_23 = bnone - raw_revbnone

xtreg diff_11 if treatment == "U80", i(id) cluster (session)
xtreg diff_12 if treatment == "U80", i(id) cluster (session)
xtreg diff_13 if treatment == "U80", i(id) cluster (session)
xtreg diff_21 if treatment == "U80", i(id) cluster (session)
xtreg diff_22 if treatment == "U80", i(id) cluster (session)
xtreg diff_23 if treatment == "U80", i(id) cluster (session)

xtreg diff_11 if treatment == "V80", i(id) cluster (session)
xtreg diff_13 if treatment == "V80", i(id) cluster (session)
xtreg diff_22 if treatment == "V80", i(id) cluster (session)
xtreg diff_23 if treatment == "V80", i(id) cluster (session)

* joint test for U80 (for V80 one probability implies the other)
reshape long diff_, i(id match) j(ball_message)

rename diff_ diff
gen d_11 = ( ball_message == 11 )
gen d_12 = ( ball_message == 12 )
gen d_13 = ( ball_message == 13 )
gen d_21 = ( ball_message == 21 )
gen d_22 = ( ball_message == 22 )
gen d_23 = ( ball_message == 23 )
gen state = 1 if ball_message <= 13
replace state = 2 if ball_message >= 21

* About the tests below. With 3 probabilities, 2 imply the third; hence if d_12 == 1, changes in the one left imply changes in the other.
* Hence, this tests whether 2 of the changes are different from 0.
* First when the ball is red
xtreg diff d_13 if state == 1 & d_12 ~= 1 & treatment == "U80", i(id) cluster( session )
test _cons = 0
test d_13 = 0, accum
* second when the ball is blue
xtreg diff d_23 if state == 2 & d_22 ~= 1 & treatment == "U80", i(id) cluster( session )
test _cons = 0
test d_23 = 0, accum

* test to compare correlation with Bayesian receivers
use "data_for_stata.dta", clear
keep if rho == 80

rename phi_bayes_com phi_bayes_1
rename phi_bayes_rev phi_bayes_2

reshape long phi_bayes_, i(id match) j(stage)
rename phi_bayes_ phi_bayes
gen stage_2 = ( stage == 2 )

bysort stage: sum phi_bayes if treatment == "U80"
bysort stage: sum phi_bayes if treatment == "V80"

xtreg phi_bayes stage_2 if treatment == "U80", i(id) cluster( session )
xtreg phi_bayes stage_2 if treatment == "V80", i(id) cluster( session )


// SECTION 4.1.2

// Footnote 25, page 19
// Data to accompany Figure 3
use "data_for_stata.dta", clear

gen post_above = ( post_red >= 0.5 ) if post_red ~= .

* U20
* rate of guessing red for key posteriors implied by commitment
tab mrdec if post_above == 0 & treatment == "U20"
tab mrdec if post_above == 1 & treatment == "U20"

* U100
* rate of guessing red for key posteriors implied by commitment
tab mrdec if post_above == 0 & treatment == "U100"
tab mrdec if post_above == 1 & treatment == "U100"

* Test comparing rates below and above
gen post_above_u20 = post_above * ( treatment == "U20" )
gen post_above_u100 = post_above * ( treatment == "U100" )
gen post_below_u20 = ( 1 - post_above ) * ( treatment == "U20" )
gen post_below_u100 = ( 1 - post_above ) * ( treatment == "U100" )
xtreg mrdec post_above_u20 post_below_u100 post_above_u100 if treatment == "U20" | treatment == "U100", i(oid) cluster(session)
* Note that FE cannot be estimated as is for the above due to collinearity
test post_above_u20 = post_above_u100 

drop post_above
gen post_above = ( post_none >= 0.5 ) if post_none ~= .

* V20
* rate of guessing red for key posteriors implied by commitment
tab mndec if post_above == 0 & treatment == "V20"
tab mndec if post_above == 1 & treatment == "V20"

* V100
* rate of guessing red for key posteriors implied by commitment
tab mndec if post_above == 0 & treatment == "V100"
tab mndec if post_above == 1 & treatment == "V100"

* Test comparing rates below and above
gen post_above_v20 = post_above * ( treatment == "V20" )
gen post_above_v100 = post_above * ( treatment == "V100" )
gen post_below_v20 = ( 1 - post_above ) * ( treatment == "V20" )
gen post_below_v100 = ( 1 - post_above ) * ( treatment == "V100" )
xtreg mndec post_above_v20 post_below_v100 post_above_v100 if treatment == "V20" | treatment == "V100", i(oid) cluster(session)
test post_above_v20 = post_above_v100 


// SECTION 4.2


// Figure 5, left panel
// Figure: Kernel density estimates of Posterior Induced by Senders
// Conditional on State
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"
sort treatment

* probability of each message when the state is RED
gen p_m_rr = ( rho/100*rred/100 ) + ( (1-rho/100)*revrred/100 )
replace p_m_rr = rred/100 if rho == 100
gen p_m_rb = ( rho/100*rblue/100 ) + ( (1-rho/100)*revrblue/100 )
replace p_m_rb = rblue/100 if rho == 100
gen p_m_rn = ( rho/100*rnone/100 ) + ( (1-rho/100)*revrnone/100 )
replace p_m_rn = rnone/100 if rho == 100
* probability of each message when the state is BLUE
gen p_m_br = ( rho/100*bred/100 ) + ( (1-rho/100)*revbred/100 )
replace p_m_br = bred/100 if rho == 100
gen p_m_bb = ( rho/100*bblue/100 ) + ( (1-rho/100)*revbblue/100 )
replace p_m_bb = bblue/100 if rho == 100
gen p_m_bn = ( rho/100*bnone/100 ) + ( (1-rho/100)*revbnone/100 )
replace p_m_bn = bnone/100 if rho == 100
* posterior if state is Red
gen post_red_state = p_m_rr*max(0,aggpost_red) + p_m_rb*max(0,aggpost_blue) + p_m_rn*max(0,aggpost_none)
gen post_blue_state = p_m_br*max(0,aggpost_red) + p_m_bb*max(0,aggpost_blue) + p_m_bn*max(0,aggpost_none)

graph tw kdensity post_red_state if v20==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if v20==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(1, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V20") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("foo" , replace)

graph tw kdensity post_red_state if v80==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if v80==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(0.6, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.2, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V80") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("bar" , replace)

graph tw kdensity post_red_state if v100==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if v100==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(0.5, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.25, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V100") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("baz" , replace)

* the vertical lines in this panel used to be the ones you would get if there was full info revelation in the commitment stage (see next line)
*xline(0.38, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.30, lpattern(dash) lcolor("gs0") lwidth(medthick))
graph tw kdensity post_red_state if u20==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if u20==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(0.331, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.3339, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U20") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("qux" , replace)

graph tw kdensity post_red_state if u80==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if u80==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(0.5, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.25, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U80") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("quux" , replace)

graph tw kdensity post_red_state if u100==1, lpattern(shortdash) color("gs8") lwidth(thick) || ///
kdensity post_blue_state if u100==1, lpattern(solid) color("gs0") lwidth(medthick) ///
xline(0.5, lpattern(dash) lcolor("gs8") lwidth(medthick)) xline(0.25, lpattern(dash) lcolor("gs0") lwidth(medthick)) ///
ytitle("Density") ///
xtitle("Posterior on Red") ///
yscale(range(0.0 18.0)) ylabel(0.0(2.0)18.0) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U100") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono)  ///
saving("quuux" , replace)

graph combine "foo.gph" "bar.gph" "baz.gph" "qux.gph" "quux.gph" "quuux.gph", ///
row(2) ///
graphregion(color(white)) scheme(s2mono) ///
note("Solid (black): B ball." "Short dash (gray): R ball." "Vertical dashed lines indicate the equilibrium predictions.", size(vsmall)) ///
saving("new_york.gph", replace)
graph export "fig_s_post_state.pdf", replace


// SECTION 5

// Table 3, page 23
// Bayesian Correlation between Ball and Guess by treatment (at the end)
// Using not the realization but the complete strategy
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"

table treatment, c(mean phi_bayes_agg)
xtreg phi_bayes_agg v80 if ( v20 == 1 | v80 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg v100 if ( v80 == 1 | v100 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg u80 if ( u20 == 1 | u80 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg u100 if ( u80 == 1 | u100 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg u20 if ( v20 == 1 | u20 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg u80 if ( v80 == 1 | u80 == 1 ), i(id) cluster(session)
xtreg phi_bayes_agg u100 if ( v100 == 1 | u100 == 1 ), i(id) cluster(session)


// SECTION 5.1

// Footnote 29, page 24
// Correlation between Ball and Guess by treatment (at the end)
// Using not the realization but the complete strategy
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"

table treatment, c(mean phi_actual_agg)


// APPENDIX B

// No of session and subjects in U100H
use "data_for_stata.dta", clear
keep if treatment == "U100H"
keep if match == 16
bysort treatment: tab date  /* number of sessions per treatment */
gen foo = .
bysort date: replace foo = _N
replace foo = 2 * foo		/* the data is organized by sender, there is a receiver for each sender */
bysort date: keep if _n == 1
sum foo                     /* number of subjects per session */
egen bar = sum(foo)
sum bar                     /* total number of subjects */


// No of session and subjects in U100S sessions
use "data_for_stata.dta", clear
keep if treatment == "U100S"
keep if match == 16
bysort treatment: tab date  /* number of sessions per treatment */
gen foo = .
bysort date: replace foo = _N
replace foo = 2 * foo		/* the data is organized by sender, there is a receiver for each sender */
bysort date: keep if _n == 1
sum foo                     /* number of subjects per session */
egen bar = sum(foo)
sum bar                     /* total number of subjects */


// APPENDIX C

// Treatment U100S
// Probability of guessing red if post >= 1/2 vs < 1/2
use "data_for_stata.dta", clear
keep if treatment == "U100S"
* independent of message color
rename mrdec dec_1
rename mbdec dec_2
reshape long dec_, i(id match) j(index_foo)
gen post_agg = aggpost_red if index_foo == 1
replace post_agg = aggpost_blue if index_foo == 2
tab dec if post_agg >= 0.5
tab dec if post_agg < 0.5
gen foo = ( post_agg >= 0.5 )

* test for difference when psoterior should and should not affect guess
xtreg dec foo, i(oid) cluster(session)


// Same as above performed seperately for each color of message
use "data_for_stata.dta", clear
keep if treatment == "U100S"
* when message is red
tab mrdec if aggpost_red >= 0.5
tab mrdec if aggpost_red < 0.5
gen foo = ( aggpost_red >= 0.5 )

* test for difference when psoterior should and should not affect guess
xtreg mrdec foo, i(oid) cluster(session)

* when message is blue
tab mbdec if aggpost_blue >= 0.5
tab mbdec if aggpost_blue < 0.5
gen bar = ( aggpost_blue >= 0.5 )

* test for difference when psoterior should and should not affect guess
xtreg mbdec bar, i(oid) cluster(session)


// Figure C12
// Figure: Estimated thresholds against Bayesian Recovered Thresholds
use "data_for_stata.dta", clear
keep if treatment == "U100S"
do "dat_threshold.do"
* comment out above three lines to go faster (after it has been run once)
save "bar.dta", replace

use "bar.dta", clear

* first get one value per subject
collapse t_t t_b b_t_t b_t_b t_m b_t_m f_t, by(oid)

* jitter values
*drop bar
gen bar = runiform()
replace bar = bar /100
gen t_m_n = t_m+bar if t_m <= 1
replace t_m_n = t_m if t_m > 1
gen b_t_m_n = b_t_m+bar if b_t_m

* generate something to identify different markers
* The next two lines are how this used to be done, we now use a less restrictive categorization based on the mean threshold
// gen skeptic = ( t_t > b_t_t & t_b > b_t_b )
// gen gullible = ( t_t < b_t_t & t_b < b_t_b )
gen skeptic = ( t_m > b_t_m )
gen gullible = ( t_m < b_t_m )

* compute how many times the same threshold/baysian-threshold occurs
bysort t_m b_t_m skeptic gullible: gen foo = _N

* Note that in this graph, a skeptic is subject who's highest possible threshold (not the mid-point) is higher than that of a Bayesian, and who's lowest possible threshold is above that of a Bayesian.
* Golluble is similarly defined.
* The white diamonds in the figure are for those who are neither skeptic not golluble.
twoway scatter t_m_n b_t_m_n if skeptic == 1 & f_t >= 0.8, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if skeptic == 1 & f_t < 0.8, msymbol(Dh) color(black) || ///
  scatter t_m_n b_t_m_n if gullible == 1 & f_t >= 0.8, msymbol(s) color(gs5) || ///
  scatter t_m_n b_t_m_n if gullible == 1 & f_t < 0.8, msymbol(Sh) color(gs5) || ///
  scatter t_m_n b_t_m_n if skeptic == 0 & gullible == 0 & f_t >= 0.8, msymbol(c) color(gs10) || ///
  scatter t_m_n b_t_m_n if skeptic == 0 & gullible == 0 & f_t < 0.8, msymbol(Ch) color(gs10) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
  note("Diamonds for subjects harder to convince than a Bayesian, square for subjects easier to convince than a Bayesian, circle otherwise." "Hollow marker for subjects whose threshold is accurate in less than 80% of cases." "Blue indicates a subject who's choices are best explained by the rule always guess blue." "Values are jittered slightly to make multiple overlapping thresholds distinguishable.", size(vsmall)) ///

graph export "fig_thresh_u100s_2.pdf", replace


// For text, fraction of subjects that follow threshold or close to it
use "bar.dta", clear
* first get one value per subject
collapse t_t f_t t_b f_b, by(oid)
* gen new dummies
gen perf_prec = (f_t >= 1)
gen med_prec = (f_t >= 0.80)

tab perf_prec
tab med_prec


// Figure C16
// Figure: Estimated Thresholds and their precision
// using the mid-point of the threshold interval
use "bar.dta", clear

* first get one value per subject
collapse t_t t_b b_t_t b_t_b t_m b_t_m f_t, by(treatment u100s oid)

* jitter values
gen bar = runiform()
replace bar = bar /100
gen f_t_n = f_t+bar

twoway scatter t_m f_t_n if u100s==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
legend(off) ///
note("Blue indicates a subject who's choices are best explained by the rule always guess blue." "Values are jittered slightly to make multiple overlapping thresholds distinguishable.", size(vsmall)) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("foo" , replace)

graph export "fig_thresh_u100s_1.pdf", replace


// Fraction close to Bayesian
use "bar.dta", clear
* first get one value per subject
collapse t_t t_b b_t_t b_t_b t_m b_t_m f_t, by(oid)
gen close = ( t_m >= b_t_m - 0.05 & t_m <= b_t_m + 0.05 )
tab close
drop close
gen close = ( t_m >= b_t_m - 0.1 & t_m <= b_t_m + 0.1 )

tab close


// Figure C13
// Figure: Estimated thresholds against Bayesian Recovered Thresholds
// using the mid-point of the threshold interval
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"
do "dat_threshold.do"
* comment out above four lines to go faster (after it has been run once)
save "foo.dta", replace

use "foo.dta", clear

* first get one value per subject
collapse t_t t_b b_t_t b_t_b t_m b_t_m f_t, by(treatment v20 v80 v100 u20 u80 u100 oid)

* drop subjects who are not close to using a threshold
drop if f_t < 0.8

* jitter values
gen bar = runiform()
replace bar = bar /100
gen t_m_n = t_m+bar if t_m <= 1
replace t_m_n = t_m if t_m > 1
gen b_t_m_n = b_t_m+bar if b_t_m

* generate something to identify different markers
* The next two lines are how this used to be done, we now use a less restrictive categorization based on the mean threshold
// gen skeptic = ( t_t > b_t_t & t_b > b_t_b )
// gen gullible = ( t_t < b_t_t & t_b < b_t_b )
gen skeptic = ( t_m > b_t_m )
gen gullible = ( t_m < b_t_m )

* compute how many times the same threshold/baysian-threshold occurs
bysort treatment t_m b_t_m skeptic gullible: gen foo = _N

* Note that in this graph, a skeptic is subject who's highest possible threshold (not the mid-point) is higher than that of a Bayesian, and who's lowest possible threshold is above that of a Bayesian.
* Golluble is similarly defined.
* The white diamonds in the figure are for those who are neither skeptic not golluble.
twoway scatter t_m_n b_t_m_n if v20==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if v20==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if v20==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("V20") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("foo" , replace)

twoway scatter t_m_n b_t_m_n if v80==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if v80==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if v80==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("V80") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("bar" , replace)

twoway scatter t_m_n b_t_m_n if v100==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if v100==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if v100==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("V100") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("baz" , replace)

twoway scatter t_m_n b_t_m_n if u20==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if u20==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if u20==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("U20") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("qux" , replace)

twoway scatter t_m_n b_t_m_n if u80==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if u80==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if u80==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("U80") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("quux" , replace)

twoway scatter t_m_n b_t_m_n if u100==1 & skeptic == 1, msymbol(d) color(black) || ///
  scatter t_m_n b_t_m_n if u100==1 & gullible == 1, msymbol(d) color(gray) || ///
  scatter t_m_n b_t_m_n if u100==1 & skeptic == 0 & gullible == 0, msymbol(diamond_hollow) color(black) || ///
  function y = x, clpat(dash) ///
  ytitle("Thresholds") ///
  xtitle("Bayesian Responder Threshold") ///
  yscale(range(0.0 1.0)) ///
  ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  yline(1.2, lstyle(foreground)) ///
  xscale(range(0.0 1.0)) ///
  xlabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
  xline(1.2, lstyle(foreground)) ///
  title("U100") ///
  legend(off) ///
  graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
saving("quuux" , replace)

graph combine "foo.gph" "bar.gph" "baz.gph" "qux.gph" "quux.gph" "quuux.gph", ///
  row(2) ///
  note("Black for subjects harder to convince than a Bayesian, gray for subjects easier to convince than a Bayesian." "Blue indicates a subject who's choices are best explained by the rule always guess blue." "Values are jittered slightly to make multiple overlapping thresholds distinguishable." "Only includes responders for whom the best fitting threshold accounts for at least 80% of choices.", size(vsmall)) ///
  graphregion(color(white)) scheme(s2mono)

graph export "fig_thresh_b.pdf", replace


// Figure C14
// Figure: Estimated Thresholds and their precision
// using the mid-point of the threshold interval
use "foo.dta", clear

* first get one value per subject
collapse t_t t_b b_t_t b_t_b t_m b_t_m f_t, by(treatment v20 v80 v100 u20 u80 u100 oid)

* jitter values
gen bar = runiform()
replace bar = bar /100
gen f_t_n = f_t+bar

twoway scatter t_m f_t_n if v20==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V20") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("foo" , replace)

twoway scatter t_m f_t_n if v80==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V80") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("bar" , replace)

twoway scatter t_m f_t_n if v100==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("V100") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("baz" , replace)

twoway scatter t_m f_t_n if u20==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U20") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("qux" , replace)

twoway scatter t_m f_t_n if u80==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U80") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("quux" , replace)

twoway scatter t_m f_t_n if u100==1, ///
ytitle("Thresholds") ///
xtitle("Precision") ///
yscale(range(0.0 1.0)) ///
ylabel(0.0 "0.0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0" 1.2 "Blue", angle(0)) ///
yline(1.2, lstyle(foreground)) ///
xscale(range(0.0 1.0)) xlabel(0.0(0.2)1.0) ///
title("U100") ///
legend(off) ///
graphregion(color(white)) bgcolor(white) scheme(s2mono) ///
msymbol(diamond_hollow) ///
saving("quuux" , replace)

graph combine "foo.gph" "bar.gph" "baz.gph" "qux.gph" "quux.gph" "quuux.gph", ///
  row(2) ///
  note("Blue indicates a subject who's choices are best explained by the rule always guess blue." "Values are jittered slightly to make multiple overlapping thresholds distinguishable.", size(vsmall)) ///
  graphregion(color(white)) scheme(s2mono)

graph export "fig_thresh_m.pdf", replace


// For text, fraction of subjects that follow threshold or close to it
use "foo.dta", clear

* first get one value per subject
collapse t_t f_t t_b f_b, by(treatment oid)

* gen new dummies
gen perf_prec = (f_t >= 1)
gen med_prec = (f_t >= 0.80)

* some stats
table treatment, c(mean med_prec)
tab med_prec
gen v = ( treatment == "V20" | treatment == "V80" | treatment == "V100" )
table v, c(mean perf_prec)


// Footnote 48 about probability matching
use "foo.dta", clear

gen e_pm = abs( mdec - post )							/* prediction error for probability matching */
gen e_pm2 = e_pm^2										/* e_pm squared */
gen t_choice = ( post >= t_m )							/* predicted choice from threshold */
gen e_t = abs( mdec - t_choice )						/* prediction error for threshold */
gen e_t2 = e_t^2										/* e_t squared */
collapse (mean) e_pm2 (mean) e_t (mean) e_t2, by(treatment oid)	/* compute mean sqared error by subject */
gen tt = ( e_t2 < e_pm2 )								/* threshold type are subjects with lower sqared mean errors for threshold than probability matching */
tab tt													/* note that no subject has e_t2 == e_mp2 */


// Figure C15
// receiver behavior as a function of rules
use "data_for_stata.dta", clear
drop if treatment == "U100S"
drop if treatment == "U100H"

rename aggpost_red aggpost1
rename aggpost_blue aggpost2
rename aggpost_no aggpost3
rename mrdec dec1
rename mbdec dec2
rename mndec dec3
reshape long aggpost dec, i(treatment session oid match) j(m_color)

gen low_post = ( aggpost >= 0 & aggpost < 0.25 )
gen high_post = ( aggpost > 0.75 & aggpost <= 1 )

keep if low_post == 1 | high_post == 1

table treatment high_post, c(mean dec)

* Figure of probability of guessing red for low and high posteriors
* numerical treatment identifier
gen treat_no = 1 if treatment == "V20"
replace treat_no = 2 if treatment == "V80"
replace treat_no = 3 if treatment == "V100"
replace treat_no = 4 if treatment == "U20"
replace treat_no = 5 if treatment == "U80"
replace treat_no = 6 if treatment == "U100"

collapse dec, by(low_post high_post treat_no)

graph bar dec, over(treat_no, relabel(1 "V20" 2 "V80" 3 "V100" 4 "U20" 5 "U80" 6 "U100")) ///
	over(high_post, relabel(1 "Posterior on Red < 0.25" 2 "Posterior on Red > 0.75")) ///
	ytitle("Probability of Guessing red") ///
	graphregion(color(white)) bgcolor(white) scheme(s2mono)

graph export "guess_extremes.pdf", replace


// APPENDIX D.4, Table D7
// Alternative Statistical Tests
do "est_flp_robust.do"


// APPENDIX D.5
use "data_for_stata.dta", clear
keep if u20 == 1 | v20 == 1

table treatment, c(mean raw_revrred mean raw_revrblue mean raw_revrnone)
table treatment, c(mean raw_revbred mean raw_revbblue mean raw_revbnone)


